@@ -2,6 +2,8 @@
 import six, os
 from say import Say, fmt, stdout
 
+globalvar = 99
+
 def setup():
     global say
     say = Say(retvalue=True)
@@ -19,6 +21,12 @@ def test_basic(param = 'Yo'):
     status = "OK"
     assert say("This is {status}", silent=True) == "This is OK"
     
+def test_gt():
+    setup()
+    
+    x = 555
+    assert (say > "{x} is a big number!") =="555 is a big number!"
+    
 def test_hr_and_title():
     setup()
     
@@ -169,4 +177,8 @@ def test_example_3():
     for item in items:
         assert say(item, indent=1) == '    ' + str(item)
   
-globalvar = 99
+def test_wrap():
+    setup()
+    assert say('abc\ndef\nghi', wrap=79) == 'abc def ghi'
+    assert say("abcde abcde abcde", wrap=6) == 'abcde\nabcde\nabcde'
+    assert say("abcde abcde abcde", wrap=10, indent=1) == '    abcde\n    abcde\n    abcde'
\ No newline at end of file
